@@ -40,9 +40,6 @@ namespace Mono.WebServer
 		public ModMonoTCPWebSource (IPAddress address, int port, string lockfile)
 			: base (lockfile)
 		{
-			if (address == IPAddress.Any)
-				address = IPAddress.Loopback;
-
 			SetListenAddress (address, port);
 		}
 		
